<?php
// $Id: filter_protocols.admin.inc,v 1.1 2010/01/25 19:35:04 davereid Exp $

/**
 * @file
 * Admin page callbacks for the filter_protocols module.
 */

function filter_protocols_settings_form() {
  // Curiously the title here is 'Text formats' so manually set the title.
  drupal_set_title(t('Allowed protocols'));

  $defaults = array(
    'ftp',
    'http',
    'https',
    'irc',
    'mailto',
    'news',
    'nntp',
    'rtsp',
    'sftp',
    'ssh',
    'telnet',
    'webcal',
  );

  $form['filter_allowed_protocols'] = array(
    '#type' => 'textfield',
    '#title' => t('Allowed protocols'),
    '#description' => t('A list of protocols that can be used.'),
    '#default_value' => implode(' ', variable_get('filter_allowed_protocols', $defaults)),
    //'#type' => 'textarea',
    //'#wysiwyg' => FALSE,
    //'#rows' => count($protocols) + 1,
    '#size' => 80,
  );

  $form = system_settings_form($form, FALSE);

  // Add a reset button.
  $form['actions']['reset'] = array(
    '#type' => 'submit',
    '#value' => t('Reset to defaults'),
    '#submit' => array('filter_protocols_settings_form_reset'),
  );

  return $form;
}

function filter_protocols_settings_form_validate($form, &$form_state) {
  $protocols = &$form_state['values']['filter_allowed_protocols'];
  $protocols = drupal_strtolower(trim($protocols));
  $protocols = preg_split('/[\W]+/', $protocols, 0, PREG_SPLIT_NO_EMPTY);
  $protocols = array_unique($protocols);
  foreach ($protocols as $protocol) {
    if (preg_match('/[^a-z]/', $protocol)) {
      form_set_error('filter_allowed_protocols', t('Invalid protocol %protocol.', array('%protocol' => $protocol)));
    }
  }
  //sort($protocols);
}

function filter_protocols_settings_form_reset($form, &$form_state) {
  variable_del('filter_allowed_protocols');
  drupal_set_message(t('The configuration options have been reset.'));
}
